classdef OutputState
    % OutputState class combines three values (8 digital, 1 analog, 1 analog) 
    % which define the output on all ports 

    properties (Hidden, Constant)
       duration = 0;  % always zero for this class
    end
    
    properties (Constant)
       ZERO = PulseStreamer.OutputState([],0,0);
    end
    
    properties (SetAccess=private)
        chans % list of digital channels to set HIGH, 
        ao0   % output value of the first analog ao0 channel (range: +/-1V)
        ao1   % output value of the second analog ao1 channel (range: +/-1V) 
    end
    
    methods
        function obj = OutputState(channels, a0, a1)
            
            if ~exist('channels', 'var')
                channels = [];
            end
            
            if ~exist('a0', 'var')
                a0 = 0;
            end
            
            if ~exist('a1', 'var')
                a1 = 0;
            end
            
            assert(isnumeric(channels), 'channels must be a list of channel numbers. Example: [0, 2, 5:7, 3]');
            assert(all(ismember(channels, 0:7)), 'Incorrect digital channel number. Valid channels are: [0:7]');
            assert(abs(a0)<=1, 'Analog channel 0: range of +-1V exceeded');
            assert(abs(a1)<=1, 'Analog channel 1: range of +-1V exceeded');
            
            obj.chans = channels;
            obj.ao0 = a0;
            obj.ao1 = a1;
        end
    end
end